@@ -42,6 +42,8 @@
 ( cd opt/kde/share/doc/HTML/et/krdc ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/krfb ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/krfb ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kscd ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kscd ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/ksim ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/ksim ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/lisa ; rm -rf common )
@@ -56,6 +58,12 @@
 ( cd opt/kde/share/doc/HTML/et/ksysguard ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kbounce ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kbounce ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kdearch ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kdearch ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kdelirc/kcmlirc ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kdelirc/kcmlirc ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kdelirc/irkick ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kdelirc/irkick ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kbattleship ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kbattleship ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kaboodle ; rm -rf common )
@@ -102,6 +110,8 @@
 ( cd opt/kde/share/doc/HTML/et/ksame ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/ksirc ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/ksirc ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/ktnef ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/ktnef ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/ksysv ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/ksysv ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/ktron ; rm -rf common )
@@ -126,6 +136,8 @@
 ( cd opt/kde/share/doc/HTML/et/kmousetool ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/ksnapshot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/klinkstatus ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/klinkstatus ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kompare ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kompare ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kontact ; rm -rf common )
@@ -158,6 +170,8 @@
 ( cd opt/kde/share/doc/HTML/et/konquest ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kspaceduel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kturtle ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kturtle ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kverbos ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kverbos ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kwallet ; rm -rf common )
@@ -404,6 +418,8 @@
 ( cd opt/kde/share/doc/HTML/et/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kicker ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kicker ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/klatin ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/klatin ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/klines ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/klines ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kmines ; rm -rf common )
@@ -416,8 +432,6 @@
 ( cd opt/kde/share/doc/HTML/et/knotes ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kpager ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kpager ; ln -sf /opt/kde/share/doc/HTML/et/common common )
-( cd opt/kde/share/doc/HTML/et/kpaint ; rm -rf common )
-( cd opt/kde/share/doc/HTML/et/kpaint ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kopete ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kopete ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kpilot ; rm -rf common )
@@ -442,6 +456,8 @@
 ( cd opt/kde/share/doc/HTML/et/kwrite ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kreversi ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kreversi ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/noatun ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/noatun ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/ksplashml ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/ksplashml ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kdebugdialog ; rm -rf common )
@@ -454,6 +470,10 @@
 ( cd opt/kde/share/doc/HTML/et/quanta ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kuickshow ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kuickshow ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kolourpaint ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kolourpaint ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kommander ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kommander ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kiconedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kiconedit ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/klettres ; rm -rf common )
@@ -466,12 +486,16 @@
 ( cd opt/kde/share/doc/HTML/et/klickety ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kpovmodeler ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kpovmodeler ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kleopatra ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kleopatra ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kjumpingcube ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kenolaba ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kenolaba ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kgpgcertmanager ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kgpgcertmanager ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kwatchgnupg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kwatchgnupg ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kworldclock ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kworldclock ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/KRegExpEditor ; rm -rf common )
@@ -524,6 +548,8 @@
 ( cd opt/kde/share/doc/HTML/et/umbrello ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/konqueror ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/konqueror ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kwordquiz ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kwordquiz ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/korganizer ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/korganizer ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/atlantik ; rm -rf common )
